@@ -20,7 +20,8 @@ extern "C"
 
 #include "gd.h"
 
-   BGD_EXPORT gdFontPtr gdFontGiant;
+   BGD_EXPORT_DATA_PROT gdFontPtr gdFontGiant;
+   BGD_DECLARE(gdFontPtr) gdFontGetGiant(void);
 
 #ifdef __cplusplus
 }
